@@ -898,28 +898,62 @@ class lazy:
             return res
 
 
-def iter_branch_subclasses(cls, include_this=True):
+def iter_branch_subclasses(cls, include_this=True, without_duplicates=False):
     """Internal function, see `get_branch_subclasses`:func:."""
-    children = type.__subclasses__(cls)
-    if children:
-        for sc in children:
-            yield from iter_branch_subclasses(sc)
-    elif include_this:
-        yield cls
+
+    def _iter(cls):
+        children = type.__subclasses__(cls)
+        if children:
+            for sc in children:
+                yield from iter_branch_subclasses(sc)
+        elif include_this:
+            yield cls
+
+    if without_duplicates:
+        from xotl.tools.future.itertools import iter_without_duplicates
+
+        return iter_without_duplicates(_iter(cls))
+    else:
+        return _iter(cls)
 
 
-def get_branch_subclasses(cls, *, include_this=False):
+def get_branch_subclasses(cls, *, include_this=False, without_duplicates=False):
     """Similar to `type.__subclasses__`:meth: but recursive.
 
-    Only return sub-classes in branches (those with no sub-classes).  Instead
-    of returning a list, yield each valid value.
+    Only return sub-classes in branches (those with no sub-classes).  Return a list of all classes
+    reachable from `cls`.
+
+    The same class can be included more than once if there are two different paths from `cls` to
+    that class::
+
+           >>> class Foo: pass
+           >>> class Bar(Foo): pass
+           >>> class Baz(Foo): pass
+           >>> class Final(Bar, Baz): pass
+
+           >>> get_branch_subclasses(Foo) == [Final, Final]
+           True
+
+
+    You can set `without_duplicates` to True to avoid this::
+
+           >>> get_branch_subclasses(Foo, without_duplicates=True) == [Final]
+           True
 
     .. versionadded:: 1.7.0
 
     .. versionchanged:: 2.1.5 Add keyword-only argument `include_this`.
 
+    .. versionchanged:: 2.2.5 Add keyword-only argument `without_duplicates`.
+
     """
-    return list(iter_branch_subclasses(cls, include_this=include_this))
+    return list(
+        iter_branch_subclasses(
+            cls,
+            include_this=include_this,
+            without_duplicates=without_duplicates,
+        )
+    )
 
 
 def FinalSubclassEnumeration(superclass, *, dynamic=True):
@@ -1573,7 +1607,7 @@ def save_attributes(obj, *attrs, getter=smart_getter, setter=smart_setter):
     `setter`.  They must take the object and return a callable to get/set the
     its attributes.
 
-    Basic example:
+    Basic example::
 
       >>> from xotl.tools.future.types import SimpleNamespace as new
       >>> obj = new(a=1, b=2)
@@ -1591,6 +1625,8 @@ def save_attributes(obj, *attrs, getter=smart_getter, setter=smart_setter):
     Depending on the behavior of `getter` and or the object itself, it may be
     an error to get an attribute or key that does not exists.
 
+    ::
+
       >>> getter = lambda o: lambda a: getattr(o, a)
       >>> with save_attributes(obj, 'c', getter=getter):   # doctest: +ELLIPSIS
       ...    pass
@@ -1600,7 +1636,7 @@ def save_attributes(obj, *attrs, getter=smart_getter, setter=smart_setter):
 
     Beware, however, that `smart_getter`:func: is non-strict by default and it
     returns None for a non-existing key or attribute.  In this case, we
-    attempt to set that attribute or key at exit:
+    attempt to set that attribute or key at exit::
 
       >>> with save_attributes(obj, 'x'):
       ...   pass
@@ -1608,7 +1644,7 @@ def save_attributes(obj, *attrs, getter=smart_getter, setter=smart_setter):
       >>> obj.x is None
       True
 
-    But, then, setting the value may fail:
+    But, then, setting the value may fail::
 
       >>> obj = object()
       >>> with save_attribute(obj, 'x'):  # doctest: +ELLIPSIS
